/*
 * Copyright: (C) 2003 Bruce W. Forsberg
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 *   Bruce Forsberg  forsberg@tns.net
 *
 */

#ifndef MILEAGE_H
#define MILEAGE_H

// This class is the main class for the program. It implements the GUI and
// widgets that are defined in the mileagebase class. The mileagebase class
// is generated by the program designer which is available with the Qtopia
// environment. This implements the 3 main tabs of the GUI.


#include "mileagebase.h"

#include <qsortedlist.h>


class mileagefile;
class milekeys;
class mileimport;
class mileagegraph;
class mileagegraphdata;


class mileage: public mainForm
{ 

public:
    mileage( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~mileage();

   void
   enterNewCar();

   void
   deleteCar();

   void
   currentCarChanged(int item);

   void
   currentGraphChanged(const QString& str);

   void
   currentGraph2Changed(const QString& str);

   void
   enterTodayDate();

   void
   submitEntry();

   void
   submitAlert();

   void
   deleteEntry();

   void
   enter0Button();
  
   void
   enter1Button();
  
   void
   enter2Button();
  
   void
   enter3Button();
  
   void
   enter4Button();
  
   void
   enter5Button();
  
   void
   enter6Button();
  
   void
   enter7Button();
  
   void
   enter8Button();
  
   void
   enter9Button();
  
   void
   enterDotButton();
  
   void
   enterSlashButton();

   void
   enterAlertButton();

   void
   enterActivityButton();

   void
   backspaceCallback();

   void
   unitsSelected(int unit);

   void
   costSelected(int cost);

   void
   updateUnits();

   void
   processTrip();

   void
   startDateKeypad();

   void
   startOdoKeypad();

   void
   endDateKeypad();

   void
   endOdoKeypad();

   void
   tripSelected(QListViewItem *item);

   // These are passed to mileageimport class
   void
   importDataCar();

private:

   mileage(mileage& op);

   const mileage&
   operator=(const mileage& op);
  
   void
   enterKeyPress(QString str);

   void
   updateCars();

   void
   updateGasData(bool update_tab);

   void
   updateActivityData();

   void
   updateAlertData();

   void
   updateTripData();

   void
   updateDisplayTab();

   void
   updateAlertDisplay();

   bool
   checkDate(
      QString& old_date,
      QString& new_date);

   void
   initTrip();


   mileagefile  *_current_car;
   milekeys     *_keys;
   mileimport   *_import;
   mileagegraph *_graph;
   int           _units;
   int           _cost;
   QSortedList<mileagegraphdata> _list;
};

#endif // MILEAGE_H
