/*
 * Copyright: (C) 2003 Bruce W. Forsberg
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 *   Bruce Forsberg  forsberg@tns.net
 *
 */

#include "mileagecfg.h"

#include <qfile.h>
#include <qfileinfo.h>
#include <qdir.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qtextstream.h>

#include <cstdio>
#include <cstdlib>

#include <iostream>

#define CAR_DATA_CFG  "mileage.cfg"


// Below is how the data is defined
// First line is units
// P - Person entry
// D - Destination entry
// C - Cost entry


// Constructor
mileagecfg::mileagecfg()
{
   QString dir_str;


   // Create directory and file
   if (getenv("HOME"))
   {
      dir_str = getenv("HOME");
      dir_str.append("/");
   }
   dir_str.append(CAR_DATA_DIR);
   _dir = new QDir();
   _dir->mkdir(dir_str, TRUE);
   _dir->setFilter(QDir::Files | QDir::NoSymLinks);
   _filestr = new QString();
   _filestr->append(dir_str);
   _filestr->append(CAR_DATA_CFG);
}


// Destructor
mileagecfg::~mileagecfg()
{
   delete _dir;
   delete _filestr;
}


int
mileagecfg::returnUnits()
{
   // IF no file present then set default of 0
   int  units = 0;


   // Read units
   QFile  filename(*_filestr);
   if (filename.open(IO_ReadOnly))
   {
      // Write out units to file
      QTextStream t(&filename);
      t >> units;
      filename.close();
   }
   return (units);
}


void
mileagecfg::setUnits(int units)
{
   // Create file and write identity string
   QFile  filename(*_filestr);
   if (filename.open(IO_ReadWrite))
   {
      // Set to beginning of file
      filename.at(0);

      // Write out units to file
      QTextStream t(&filename);
      t << units << endl;
      filename.close();
   }
}


void
mileagecfg::returnPersons(QStringList & persons)
{
   QFile filename(*_filestr);
   QString  n_str;

   // Open the file for reading
   if (filename.open(IO_ReadOnly))
   {
      QTextStream t(&filename);

      while (!t.atEnd())
      {
         QString  str = t.readLine();
         QChar chr = str.at(0);
         if (chr == "P")
         {
            n_str = str.right(str.length()-2);
            persons << n_str;
         }
      }
      filename.close();
   }
}


void
mileagecfg::setPerson(QString & person)
{
   QFile filename(*_filestr);
   QStringList  person_list;


   if (person.length() != 0)
   {
      returnPersons(person_list);

      // IF person is not already in list
      if (person_list.find(person) == person_list.end())
      {
         // Open file to write at end
         if (filename.open(IO_ReadWrite | IO_Append))
         {
            // write line to file
            QTextStream t(&filename);
            t << "P " << person << endl;

            filename.close();
         }
      }
   }
}


void
mileagecfg::returnDestinations(QStringList & dest)
{
   QFile filename(*_filestr);
   QString  n_str;

   // Open the file for reading
   if (filename.open(IO_ReadOnly))
   {
      QTextStream t(&filename);

      while (!t.atEnd())      
      {      
         QString  str = t.readLine();      
         QChar chr = str.at(0);      
         if (chr == "D")
         {      
            n_str = str.right(str.length()-2);      
            dest << n_str;
         }      
      }      
      filename.close();
   }
}


void
mileagecfg::setDestination(QString & dest)
{
   QFile filename(*_filestr);
   QStringList  dest_list;


   if (dest.length() != 0)
   {
      returnDestinations(dest_list);

      // IF destination is not already in list
      if (dest_list.find(dest) == dest_list.end())
      {
         // Open file to write at end
         if (filename.open(IO_ReadWrite | IO_Append))
         {
            // write line to file
            QTextStream t(&filename);
            t << "D " << dest << endl;

            filename.close();
         }
      }
   }
}


int
mileagecfg::returnCostUnits()
{
   // IF no file present then set default of 0
   int  units = 0;
   QFile filename(*_filestr);
   QString  n_str;

   // Open the file for reading
   if (filename.open(IO_ReadOnly))
   {
      QTextStream t(&filename);

      while (!t.atEnd())
      {
         QString  str = t.readLine();
         QChar chr = str.at(0);
         if (chr == "C")
         {
            QString f_tag;
            QTextStream s(&str, IO_ReadOnly);
            s >> f_tag;
            s >> units;
         }
      }
      filename.close();
   }

   return (units);
}


void
mileagecfg::setCostUnits(int cost)
{
   int pos = 0;

   // Create file and write identity string
   QFile  filename(*_filestr);
   if (filename.open(IO_ReadWrite))
   {
      QTextStream t(&filename);

      while (!t.atEnd())
      {
         QString  str = t.readLine();
         QChar chr = str.at(0);
         if (chr == "C")
         {
            filename.at(pos);

            // Write out units to file
            QTextStream to(&filename);
            to << "C " << cost << endl;
            pos = -1;
            break;
         }
         // TBD will this cause problems
         pos = filename.at();
      }
      filename.close();

      if (pos != -1)
      {
         // Open file to write at end
         if (filename.open(IO_ReadWrite | IO_Append))
         {
            // write line to file
            QTextStream t(&filename);
            t << "C " << cost << endl;

            filename.close();
         }
      }
   }
}


