/*
 * Copyright: (C) 2003 Bruce W. Forsberg
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 *   Bruce Forsberg  forsberg@tns.net
 *
 */

#ifndef MILEAGEGRAPH_H
#define MILEAGEGRAPH_H

#include <qsortedlist.h>
#include <qpen.h>
#include <qwidget.h>

#include "mileagegraphdata.h"

class QWidget;
class QPainter;
class QPointArray;
class QString;
class QComboBox;
class QPaintEvent;


class mileagegraph : public QWidget
{ 

public:
   mileagegraph(QSortedList<mileagegraphdata>& lst,
                QWidget* parent, const char* name);
   ~mileagegraph();

   void
   createPens();

   void
   paintEvent(QPaintEvent *e);

   void
   currentGraphChanged(const QString& str);

   void
   currentGraph2Changed(const QString& str);

   void
   currentCarChanged(QComboBox *year);

   void
   setUnits(
      int units,
      int cost);

private:

   mileagegraph(mileagegraph& op);

   const mileagegraph&
   operator=(const mileagegraph& op);

   void
   drawGrid(QPainter *p);

   void
   drawData(QPainter *p);

   void
   drawText(QPainter *p);

   void
   drawLegend(
   int year,
   QPainter *p);

   void
   graphMileageYear(
      int year,
      QPainter *p);

   void
   graphDistanceYear(
      int year,
      QPainter *p);

   void
   graphCostYear(
      int year,
      QPainter *p);

   int
   getMaxDistance();

   int
   getMaxMileage();

   int
   getMaxCost();

   void
   graphIt(
      int year,
      QPainter *p);


QSortedList<mileagegraphdata>&  _list;
QString   _graphtype;
QString   _graphtype2;
QString   _dist;
QString   _mile;
QString   _cost_str;
int       _units;
int       _cost;
QPen     _pen_graph;
QPen     _pen[8];
int       _first_year;
int       _last_year;
int       _max_dist;
int       _max_mileage;
int       _max_display;
int       _max_cost;

};

#endif // MILEAGEGRAPH_H
