/*
 * Copyright: (C) 2004 Bruce W. Forsberg
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 *   Bruce Forsberg  forsberg@tns.net
 *
 */


#include "mileimport.h"

#include <qfile.h>
#include <qlineedit.h>
#include <qmessagebox.h>
#include <qcombobox.h>
#include <qtextstream.h>
#include <qlistview.h>

#include <cstdio>
#include <cstdlib>
#include <iostream>


// Constructor
mileimport::mileimport(
   QWidget* parent,
   const char* name,
   WFlags fl ) : importForm( parent, name, fl )
{
   _lst = new QStringList();
   _cols = 0;
   _date = 0;
   _odo = 0;
   _fuel = 0;
   _cost = 0;
}

// Destructor
mileimport::~mileimport()
{
   delete _lst;
}


void
mileimport::readFile()
{
   QString s;

   _lst->clear();
   _cols = 0;
   _date = 0;
   _odo = 0;
   _fuel = 0;
   _cost = 0;

   QFile * fil = new QFile(importEdit->text());
   if (fil->exists())
   {
      if (fil->open(IO_ReadOnly))
      {
         while(fil->readLine(s, 512) > 0)
         {
            _lst->append(s);
         }
         fil->close();

         if (verifyFile())
         {
            fillMenus();
         }
      }
   }
   else
   {
      QMessageBox::information(this, "Warning", "Can't find file specified.",
         QMessageBox::Ok);
   }

   delete fil;
}


void
mileimport::fillMenus()
{
    int i;

   // clear out any old items
   dateFieldBox->clear();
   odoFieldBox->clear();
   fuelFieldBox->clear();
   costFieldBox->clear();

   // Set default selection of No Field
   dateFieldBox->insertItem("No Field");
   odoFieldBox->insertItem("No Field");
   fuelFieldBox->insertItem("No Field");
   costFieldBox->insertItem("No Field");

   // Add a field for each field in file
   for (i = 1; i <= _cols; i++)
   {
      dateFieldBox->insertItem("Field " + QString::number(i));
      odoFieldBox->insertItem("Field " + QString::number(i));
      fuelFieldBox->insertItem("Field " + QString::number(i));
      costFieldBox->insertItem("Field " + QString::number(i));
   }
}


bool
mileimport::verifyFile()
{
   // TBD for now set cols
   _cols = 5;

   return(TRUE);
}


void
mileimport::processDate(int field)
{
   _date = field;

   displayTable();
}


void
mileimport::processOdo(int field)
{
   _odo = field;

   displayTable();
}


void
mileimport::processFuel(int field)
{
   _fuel = field;

   displayTable();
}


void
mileimport::processCost(int field)
{
   _cost = field;

   displayTable();
}


void
mileimport::displayTable()
{
   importView->clear();

   for (QStringList::Iterator it = _lst->begin(); it != _lst->end(); it++)
   {
      QString date_str;
      QString odo_str;
      QString fuel_str;
      QString cost_str;
      QListViewItem  *item = NULL;
      QString str = *it;
      QChar chr = ',';

      if (_date > 0)
      {
      }

      if (_odo > 0)
      {
         int index = 0;
         QString new_str;
         double d_odo;
         int odo;

         for (int i = 0; i < _odo-1; i++)
         {
            index = str.find(chr, index);
            index++;
         }

         new_str = str.right(str.length() - index);
         QTextStream  ts(new_str, IO_ReadOnly);

         ts >> d_odo;
         odo = (int)d_odo;
         odo_str.setNum(odo);
      }

      if (_fuel > 0)
      {
         int index = 0;
         QString new_str;
         double d_fuel;

         for (int i = 0; i < _fuel-1; i++)
         {
            index = str.find(chr, index);
            index++;
         }

         new_str = str.right(str.length() - index);
         QTextStream  ts(new_str, IO_ReadOnly);

         ts >> d_fuel;
         fuel_str.setNum(d_fuel);
      }

      if (_cost > 0)
      {
         int index = 0;      
         QString new_str;      
         double d_cost;

         for (int i = 0; i < _cost-1; i++)
         {
            index = str.find(chr, index);      
            index++;
         }

         new_str = str.right(str.length() - index);      
         QTextStream  ts(new_str, IO_ReadOnly);

         ts >> d_cost;
         cost_str.setNum(d_cost);
      }

      item = new QListViewItem(importView, item,
             date_str, odo_str, fuel_str, cost_str);
   }
}


