/*
 * Copyright: (C) 2003 Bruce W. Forsberg
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 *   Bruce Forsberg  forsberg@tns.net
 *
 */


#include "milekeys.h"

#include <qlineedit.h>
#include <qdatetime.h>
#include <qpushbutton.h>

#include <cstdio>
#include <cstdlib>
#include <iostream>


// Constructor
milekeys::milekeys(
   bool       date,
   QLineEdit *edit,
   QWidget* parent,
   const char* name,
   WFlags fl ) : keypadForm( parent, name, fl )
{
   _edit = edit;
   buttonDate->setDisabled(date);
}

// Destructor
milekeys::~milekeys()
{
}


// This is called when the user presses the Enter Today's Date button
void
milekeys::enterTodayDate()
{
   QDate date = QDate::currentDate();
   QString str = QString::number(date.year()) + "/" +
                 QString::number(date.month()) + "/" +
                 QString::number(date.day());
   _edit->validateAndSet(str, 0, 0, 0);
   _edit->cursorRight(0, str.length());
}


// Called when user presses 0 on the GUI button
void
milekeys::enter0Button()
{
   enterKeyPress("0");
}

// Called when user presses 1 on the GUI button
void
milekeys::enter1Button()
{
   enterKeyPress("1");
}

// Called when user presses 2 on the GUI button
void
milekeys::enter2Button()
{
   enterKeyPress("2");
}

// Called when user presses 3 on the GUI button
void
milekeys::enter3Button()
{
   enterKeyPress("3");
}

// Called when user presses 4 on the GUI button
void
milekeys::enter4Button()
{
   enterKeyPress("4");
}

// Called when user presses 5 on the GUI button
void
milekeys::enter5Button()
{
   enterKeyPress("5");
}

// Called when user presses 6 on the GUI button
void
milekeys::enter6Button()
{
   enterKeyPress("6");
}

// Called when user presses 7 on the GUI button
void
milekeys::enter7Button()
{
   enterKeyPress("7");
}

// Called when user presses 8 on the GUI button
void
milekeys::enter8Button()
{
   enterKeyPress("8");
}

// Called when user presses 9 on the GUI button
void
milekeys::enter9Button()
{
   enterKeyPress("9");
}

// Called when user presses . on the GUI button
void
milekeys::enterDotButton()
{
   enterKeyPress(".");
}

// Called when user presses / on the GUI button
void
milekeys::enterSlashButton()
{
   enterKeyPress("/");
}

// Called when user wishes to delete a character
void
milekeys::backspaceCallback()
{
   enterKeyPress("backspace");
}


// This is called when a user presses the key pad. It checks for which text
// box has focus to enter data there.
void
milekeys::enterKeyPress(QString str)
{
   if (str == "backspace")
   {
      _edit->backspace();
   }
   else
   {
      // Enter key press into text box at end of text
      QString new_str = _edit->text() + str;
      _edit->validateAndSet(new_str, 0, 0, 0);
      _edit->cursorRight(0, new_str.length());
   }
}

